@@ -1,7 +1,7 @@
 """
 exception raise by this package
 """
-# Copyright (c) 2018-2020 Trim21 <i@trim21.me>
+# Copyright (c) 2018-2021 Trim21 <i@trim21.me>
 # Copyright (c) 2008-2014 Erik Svensson <erik.public@gmail.com>
 # Licensed under the MIT license.
 from typing import Optional
@@ -17,15 +17,15 @@ class TransmissionError(Exception):
     """
 
     def __init__(self, message: str = "", original: Optional[Response] = None):
-        Exception.__init__(self)
+        super().__init__()
         self.message = message
         self.original = original
 
     def __str__(self) -> str:
         if self.original:
             original_name = type(self.original).__name__
-            return '{} Original exception: {}, "{}"'.format(
-                self.message, original_name, str(self.original)
+            return (
+                f'{self.message} Original exception: {original_name}, "{self.original}"'
             )
         return self.message
 
@@ -40,3 +40,7 @@ class TransmissionConnectError(TransmissionError, requests.exceptions.Connection
 
 class TransmissionTimeoutError(TransmissionConnectError, requests.exceptions.Timeout):
     """Timeout"""
+
+
+class TransmissionVersionError(TransmissionError):
+    """transmission version is too lower to support some feature"""
