@@ -1,4 +1,4 @@
-# Copyright (c) 2020 Trim21 <i@trim21.me>
+# Copyright (c) 2020-2021 Trim21 <i@trim21.me>
 # Copyright (c) 2008-2014 Erik Svensson <erik.public@gmail.com>
 # Licensed under the MIT license.
 # pylint: disable=C0103
@@ -42,7 +42,7 @@ def get_status_new(code: int) -> str:
 
 
 class Status(str):
-    """A class wrap torrent status.
+    """A wrapped ``str`` for torrent status.
 
     returned by :py:attr:`.Torrent.status`
     """
@@ -112,7 +112,7 @@ class Torrent:
         try:
             return self._fields[name].value
         except KeyError:
-            raise AttributeError("No attribute %s" % name) from None
+            raise AttributeError(f"No attribute {name}") from None
 
     def _rpc_version(self) -> int:
         """Get the Transmission RPC API version."""
